## Llama-Parse RAG

create a readme.md file markdown all in one shot with below details

1. install the project using `pip install bootstrap-rag`
2. run the bootstrap-rag using `bootstraprag create <your_project_name>`
3. select llamaindex
4. select rag-with-llama-parse
5. change the details accordingly in `.env` example DB_URL, DB_PASSWORD, LLAMA_CLOUD api key etc.
6. run `python main.py`